#!/bin/sh
# mingw-find-files.sh - automagically generate file list
# for inclusion in an rpm spec file for mingw-* packages.

PACKAGE_NAME=$1
BUILDDIR=$2
shift 2

for target in $@; do
	prefix=`rpm --eval "%{${target}_prefix}"`
	# generate the filelist for static libs
	find $RPM_BUILD_ROOT$prefix -type f -name "*.a" -and ! -name "*.dll.a" |
		sed -n -e "s#^$RPM_BUILD_ROOT##p" > $BUILDDIR/${target}-staticfiles.list
	# generate directory list
	find $RPM_BUILD_ROOT$prefix -type d |
		sed -n -e "s#^$RPM_BUILD_ROOT##p" | sort > $BUILDDIR/${target}-dir.list
	# generate list of all file in the $RPM_BUILD_ROOT
	find $RPM_BUILD_ROOT$prefix -type f |
		sed -n -e "s#^$RPM_BUILD_ROOT##p" | sort > $BUILDDIR/${target}-allfiles.list
	# generate list of file comes from the base mingw-filesystem packges
	rpm -ql ${target}-filesystem | sort > $BUILDDIR/${target}-filesystemfiles.list
	# generate directory list not added by the base mingw-filesystem packges ie. owned by this package
	comm -13 $BUILDDIR/${target}-{filesystemfiles,dir}.list |
		sed -n -e "s#^/#%dir /#p" > $BUILDDIR/${target}-files.list
	# since %files can on have one -f agrument we need one common files with all files
	# if we have ${target}-$PACKAGE_NAME.lang ie generated by mingw-lang.sh than
	# add it's content to the final result ${target}-files.list
	# ${target}-otherfiles.list contains all files own by any other subpackage
	if [ -f $BUILDDIR/${target}-$PACKAGE_NAME.lang ]; then
		cat $BUILDDIR/${target}-$PACKAGE_NAME.lang >> $BUILDDIR/${target}-files.list
		sort $BUILDDIR/${target}-{{filesystem,static}files.list,$PACKAGE_NAME.lang} > \
			$BUILDDIR/${target}-otherfiles.list
	else
		sort $BUILDDIR/${target}-{filesystem,static}files.list > $BUILDDIR/${target}-otherfiles.list
	fi
	comm -13 $BUILDDIR/${target}-{other,all}files.list >> $BUILDDIR/${target}-files.list
done
